@@ -5,7 +5,6 @@ import os
 import json
 import sys
 import importlib
-from spotpython.hyperparameters.values import get_tuned_architecture
 from spotpython.utils.eda import gen_design_table
 from spotpython.utils.init import setup_paths
 
@@ -120,29 +119,48 @@ def get_result_filename(PREFIX) -> str:
     return filename
 
 
-def load_result(PREFIX) -> tuple:
+def _handle_res_filneame(filename, PREFIX):
+    if filename is None:
+        if PREFIX is None:
+            raise ValueError("No PREFIX provided.")
+        filename = get_result_filename(PREFIX)
+    return filename
+
+
+def _handle_exp_filneame(filename, PREFIX):
+    if filename is None:
+        if PREFIX is None:
+            raise ValueError("No PREFIX provided.")
+        filename = get_experiment_filename(PREFIX)
+    return filename
+
+
+def load_result(PREFIX=None, filename=None) -> tuple:
     """Loads the result from a pickle file with the name
     PREFIX + "_res.pkl".
     This is the standard filename for the result file,
     when it is saved by the spot tuner using `save_result()`, i.e.,
     when fun_control["save_result"] is set to True.
+    If a filename is provided, the result is loaded from this file.
 
     Args:
-        PREFIX (str): Prefix of the experiment.
+        PREFIX (str): Prefix of the experiment. Defaults to None.
+        filename (str): Name of the pickle file. Defaults to None.
 
     Returns:
-        (spot_tuner, fun_control, design_control, surrogate_control, optimizer_control): Tuple of objects.
+        spot_tuner (Spot): The spot tuner object.
+
+    Notes:
+        The corresponding save_result function is part of the class spot.
 
     Examples:
         >>> from spotpython.utils.file import load_result
         >>> load_result("branin")
 
     """
-    if PREFIX is None:
-        raise ValueError("No PREFIX provided.")
-    filename = get_result_filename(PREFIX)
-    spot_tuner, fun_control, design_control, surrogate_control, optimizer_control = load_experiment(filename=filename)
-    return spot_tuner, fun_control, design_control, surrogate_control, optimizer_control
+    filename = _handle_res_filneame(filename, PREFIX)
+    spot_tuner = load_experiment(filename=filename)
+    return spot_tuner
 
 
 def load_experiment(PREFIX=None, filename=None):
@@ -159,11 +177,7 @@ def load_experiment(PREFIX=None, filename=None):
         filename (str): Name of the pickle file. Defaults to None.
 
     Returns:
-        spot_tuner (object): The spot tuner object.
-        fun_control (dict): The function control dictionary.
-        design_control (dict): The design control dictionary.
-        surrogate_control (dict): The surrogate control dictionary.
-        optimizer_control (dict): The optimizer control dictionary.
+        spot_tuner (Spot): The spot tuner object.
 
     Notes:
         The corresponding save_experiment function is part of the class spot.
@@ -173,38 +187,11 @@ def load_experiment(PREFIX=None, filename=None):
         >>> spot_tuner, fun_control, design_control, _, _ = load_experiment(filename="RUN_0.pkl")
 
     """
-    if filename is None and PREFIX is not None:
-        filename = get_experiment_filename(PREFIX)
+    filename = _handle_exp_filneame(filename, PREFIX)
     with open(filename, "rb") as handle:
-        experiment = pickle.load(handle)
+        spot_tuner = pickle.load(handle)
         print(f"Loaded experiment from {filename}")
-    # assign spot_tuner and fun_control only if they exist otherwise throw an error
-    if "spot_tuner" not in experiment:
-        raise ValueError("The spot tuner object does not exist in the pickle file.")
-    if "fun_control" not in experiment:
-        raise ValueError("The fun control dictionary does not exist in the pickle file.")
-    spot_tuner = experiment["spot_tuner"]
-    fun_control = experiment["fun_control"]
-    # assign the rest of the dictionaries if they exist otherwise assign None
-    if "design_control" not in experiment:
-        design_control = None
-        # issue a warning
-        print("The design control dictionary does not exist in the pickle file. Returning None.")
-    else:
-        design_control = experiment["design_control"]
-    if "surrogate_control" not in experiment:
-        surrogate_control = None
-        # issue a warning
-        print("The surrogate control dictionary does not exist in the pickle file. Returning None.")
-    else:
-        surrogate_control = experiment["surrogate_control"]
-    if "optimizer_control" not in experiment:
-        # issue a warning
-        print("The optimizer control dictionary does not exist in the pickle file. Returning None.")
-        optimizer_control = None
-    else:
-        optimizer_control = experiment["optimizer_control"]
-    return spot_tuner, fun_control, design_control, surrogate_control, optimizer_control
+    return spot_tuner
 
 
 def load_dict_from_file(coremodel, dirname="userModel"):
@@ -246,43 +233,6 @@ def load_core_model_from_file(coremodel, dirname="userModel"):
     return core_model
 
 
-def get_experiment_from_PREFIX(PREFIX, return_dict=True) -> dict:
-    """
-    Setup the experiment based on the PREFIX provided and return the relevant configuration
-    and control objects.
-
-    Args:
-        PREFIX (str):
-            The prefix for the experiment filename.
-        return_dict (bool, optional):
-            Whether to return the configuration and control objects as a dictionary.
-            If False, a tuple is returned:
-            "(config, fun_control, design_control, surrogate_control, optimizer_control)."
-            Defaults to True.
-
-    Returns:
-        dict: Dictionary containing the configuration and control objects.
-
-    Example:
-        >>> from spotpython.utils.file import get_experiment_from_PREFIX
-        >>> config = get_experiment_from_PREFIX("100")["config"]
-
-    """
-    experiment_name = get_experiment_filename(PREFIX)
-    spot_tuner, fun_control, design_control, surrogate_control, optimizer_control = load_experiment(experiment_name)
-    config = get_tuned_architecture(spot_tuner, fun_control)
-    if return_dict:
-        return {
-            "config": config,
-            "fun_control": fun_control,
-            "design_control": design_control,
-            "surrogate_control": surrogate_control,
-            "optimizer_control": optimizer_control,
-        }
-    else:
-        return config, fun_control, design_control, surrogate_control, optimizer_control
-
-
 def load_and_run_spot_python_experiment(spot_filename) -> tuple:
     """Loads and runs a spot experiment.
 
